@@ -62,16 +62,18 @@ public:
   virtual Glib::ustring get_contents() const;
   virtual void set_contents(const Glib::ustring& strVal);
 
+  virtual Glib::ustring get_file_uri_with_extension(const Glib::ustring& uri);
+
   virtual Glib::ustring get_file_uri() const;
   virtual void set_file_uri(const Glib::ustring& file_uri, bool bEnforceFileExtension = false);
 
   ///Gets filename part of file_uri, or 'untitled'.
   virtual Glib::ustring get_name() const;
-  static Glib::ustring util_file_uri_get_name(const Glib::ustring& file_uri);
+  static Glib::ustring util_file_uri_get_name(const Glib::ustring& file_uri, const Glib::ustring& file_extension);
 
   virtual bool get_read_only() const;
   virtual void set_read_only(bool bVal);
-  
+
   ///If you don't want to use a View, then don't use set_view().
   virtual void set_view(ViewBase* pView);
   virtual ViewBase* get_view();
@@ -114,7 +116,7 @@ protected:
 
   Glib::ustring m_strContents;
   Glib::ustring m_file_uri;
-  Glib::ustring m_strFileExtension;
+  Glib::ustring m_file_extension;
 
   ViewBase* m_pView;
 
